@@ -62,34 +62,33 @@ import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionSession;
 import com.openexchange.tools.iterator.SearchIterator;
 
-
 /**
  * {@link ContactFolderUpdaterStrategy}
- *
+ * 
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
- *
  */
 public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Contact> {
-    
+
     private static final int SQL_INTERFACE = 1;
+
     private static final int SUBSCRIPTION = 2;
-    
+
     private static final int[] COMPARISON_COLUMNS = {
         Contact.OBJECT_ID, Contact.FOLDER_ID, Contact.GIVEN_NAME, Contact.SUR_NAME, Contact.BIRTHDAY, Contact.DISPLAY_NAME, Contact.EMAIL1,
         Contact.EMAIL2, Contact.EMAIL3 };
-    
+
     public int calculateSimilarityScore(Contact original, Contact candidate, Object session) throws AbstractOXException {
         int score = 0;
         // For the sake of simplicity we assume that equal names mean equal contacts
         // TODO: This needs to be diversified in the form of "unique-in-context" later (if theres only one "Max Mustermann" in a folder it
         // is unique and qualifies as identifier. If there are two "Max Mustermann" it does not.)
-        if (eq(original.getGivenName(), candidate.getGivenName())) {
+        if ((isset(original.getGivenName()) || isset(candidate.getGivenName())) && eq(original.getGivenName(), candidate.getGivenName())) {
             score += 5;
         }
-        if (eq(original.getSurName(), candidate.getSurName())) {
+        if ((isset(original.getSurName()) || isset(candidate.getSurName())) && eq(original.getSurName(), candidate.getSurName())) {
             score += 5;
         }
-        if (eq(original.getDisplayName(), candidate.getDisplayName())) {
+        if ((isset(original.getDisplayName()) || isset(candidate.getDisplayName())) && eq(original.getDisplayName(), candidate.getDisplayName())) {
             score += 10;
         }
         // an email-address is unique so if this is identical the contact should be the same
@@ -109,6 +108,10 @@ public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Conta
         return score;
     }
 
+    private boolean isset(String s) {
+        return s == null || s.length() > 0;
+    }
+
     protected boolean eq(Object o1, Object o2) {
         if (o1 == null || o2 == null) {
             return false;
@@ -118,17 +121,23 @@ public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Conta
     }
 
     public void closeSession(Object session) throws AbstractOXException {
-        
+
     }
 
     public Collection<Contact> getData(Subscription subscription, Object session) throws AbstractOXException {
         RdbContactSQLImpl contacts = (RdbContactSQLImpl) getFromSession(SQL_INTERFACE, session);
-        
+
         int folderId = subscription.getFolderIdAsInt();
         int numberOfContacts = contacts.getNumberOfContacts(folderId);
-        SearchIterator<Contact> contactsInFolder = contacts.getContactsInFolder(folderId, 0, numberOfContacts, Contact.OBJECT_ID, "ASC", COMPARISON_COLUMNS);
+        SearchIterator<Contact> contactsInFolder = contacts.getContactsInFolder(
+            folderId,
+            0,
+            numberOfContacts,
+            Contact.OBJECT_ID,
+            "ASC",
+            COMPARISON_COLUMNS);
         List<Contact> retval = new ArrayList<Contact>();
-        while(contactsInFolder.hasNext()) {
+        while (contactsInFolder.hasNext()) {
             retval.add(contactsInFolder.next());
         }
         return retval;
@@ -146,11 +155,10 @@ public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Conta
         RdbContactSQLImpl contacts = (RdbContactSQLImpl) getFromSession(SQL_INTERFACE, session);
         Subscription subscription = (Subscription) getFromSession(SUBSCRIPTION, session);
         newElement.setParentFolderID(subscription.getFolderIdAsInt());
-        
+
         contacts.insertContactObject(newElement);
     }
 
-
     private Object getFromSession(int key, Object session) {
         return ((Map<Integer, Object>) session).get(key);
     }
